import { createSignal, onCleanup } from "solid-js";
/**
 * Querying the permission API
 *
 * @param name permission name (e.g. "microphone") or a PermissionDescriptor object (`{ name: ... }`)
 * @returns "unknown" | "pending" | "granted" | "rejected"
 */
export const createPermission = (name) => {
    const [permission, setPermission] = createSignal("unknown");
    navigator.permissions.query(typeof name === "string" ? { name } : name).then(status => {
        setPermission(status.state);
        const listener = () => setPermission(status.state);
        status.addEventListener("change", listener);
        onCleanup(() => {
            status.removeEventListener("change", listener);
        });
    });
    return permission;
};
